Unmount

Trait Unmount 

pub trait Unmount {
    // Required method
    fn unmount(&self, flags: UnmountFlags) -> Result<()>;

    // Provided method
    fn into_unmount_drop(self, flags: UnmountFlags) -> UnmountDrop<Self>
       where Self: Sized { ... }
}
Unmount trait which enables any type that implements it to be upgraded into an UnmountDrop.

Required Methods

fn unmount(&self, flags: UnmountFlags) -> Result<()>

Unmount this mount with the given flags.

This will also detach the loopback device that the mount is assigned to, if it was associated with a loopback device.

Errors

On failure to unmount

Provided Methods

fn into_unmount_drop(self, flags: UnmountFlags) -> UnmountDrop<Self>
where Self: Sized,

Upgrades Self into an UnmountDrop, which will unmount the mount when it is dropped.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors