pub trait Unmount {
// Required method
fn unmount(&self, flags: UnmountFlags) -> Result<()>;
// Provided method
fn into_unmount_drop(self, flags: UnmountFlags) -> UnmountDrop<Self>
where Self: Sized { ... }
}Expand description
Unmount trait which enables any type that implements it to be upgraded into an UnmountDrop.
Required Methods
Provided Methods
Sourcefn into_unmount_drop(self, flags: UnmountFlags) -> UnmountDrop<Self>where
Self: Sized,
fn into_unmount_drop(self, flags: UnmountFlags) -> UnmountDrop<Self>where
Self: Sized,
Upgrades Self into an UnmountDrop, which will unmount the mount when it is dropped.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".